@@ -1,5 +1,5 @@
 package Class::groups ;
-$VERSION = 1.78 ;
+$VERSION = 1.79 ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
@@ -105,7 +105,9 @@ $VERSION = 1.78 ;
                     { croak qq(Odd number of arguments for "$n", died)
                     }
                  ; while ( my ($p, $v) = each %$data )  # set
-                    { if ( my $m = $s->can($p) )
+                    { if ( my $m = $s->can($p)
+                           and grep /^$p$/, @group_props
+                         )
                        { $s->$m($v)
                        }
                       else
@@ -136,9 +138,9 @@ __END__
 
 Class::groups - Pragma to implement group of properties
 
-=head1 VERSION 1.78
+=head1 VERSION 1.79
 
-Included in OOTools 1.78 distribution.
+Included in OOTools 1.79 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
